==> pigment_0.5.1.orig.tar.gz: Pigment-0.5.1/README.md <==
<p align="center"><img width="128" src="https://jeffser.com/images/pigment/logo.svg">
<h1 align="center">Pigment</h1>

<p align="center">Pigment allows you to quickly extract a color palette from any image offline.</p>

<p align="center"><a href='https://flathub.org/apps/com.jeffser.Pigment'><img width='190' alt='Download on Flathub' src='https://flathub.org/api/badge?locale=en'/></a></p>

---

> [!IMPORTANT]
> Please be aware that [GNOME Code of Conduct](https://conduct.gnome.org) applies to Pigment before interacting with this repository.

> [!WARNING]
> AI generated issues and PRs will be denied, repeated offense will result in a ban from the repository.

<p align="center">
    &#128073; <a href="https://github.com/Jeffser/Alpaca/discussions/793"><b>Initial Annoucement in the Alpaca project</b></a>
</p>

## Screenies

| ![Screenie 1](https://jeffser.com/images/pigment/screenie1.png) | ![Screenie 2](https://jeffser.com/images/pigment/screenie2.png) |
|:---------------------------------------------------------------:|:---------------------------------------------------------------:|
| ![Screenie 3](https://jeffser.com/images/pigment/screenie3.png) | ![Screenie 4](https://jeffser.com/images/pigment/screenie4.png) |

## Installation

> [!TIP]
> You may need to [install Flatpak and add the Flathub repository](https://flathub.org/setup) if you haven't already.

### Flathub

Use your system's app store to find Pigment or run this command to install it.

```BASH
flatpak install com.jeffser.Pigment
```

### Package

Pigment is distributed with Flatpak - make sure your distribution supports Flatpak before installing Pigment!

1. Download the latest Flatpak package from the [releases page](https://github.com/Jeffser/Pigment/releases)
2. Open it
3. Install the application
4. Enjoy!

## Translators

Language               | Contributors
:----------------------|:-----------
🇪🇸 Spanish             | [Jeffry Samuel](https://github.com/jeffser)
🇮🇳 Telugu              | [Aryan Karamtoth](https://github.com/SpaciousCoder78)
🇩🇪 German              | [Magnus Schlinsog](https://github.com/mags0ft)
🇮🇳 Bengali             | [Aritra Saha](https://github.com/olumolu)
🇮🇳 Hindi               | [Aritra Saha](https://github.com/olumolu)
🇨🇿 Czech               | [Amerey](https://github.com/Amereyeu)
🌐 Arabic              | [Zefr0x](https://github.com/zefr0x)

## Thanks

Made using [ColorThief](https://github.com/fengsp/color-thief-py).

==> pigment_0.5.5.orig.tar.gz: Pigment-0.5.5/README.md <==
<p align="center"><img width="128" src="https://jeffser.com/images/pigment/logo.svg">
<h1 align="center">Pigment</h1>

<p align="center">Pigment allows you to quickly extract a color palette from any image offline.</p>

<p align="center"><a href='https://flathub.org/apps/com.jeffser.Pigment'><img width='190' alt='Download on Flathub' src='https://flathub.org/api/badge?locale=en'/></a></p>

---

> [!IMPORTANT]
> Please be aware that [GNOME Code of Conduct](https://conduct.gnome.org) applies to Pigment before interacting with this repository.

> [!WARNING]
> AI generated issues and PRs will be denied, repeated offense will result in a ban from the repository.

<p align="center">
    &#128073; <a href="https://github.com/Jeffser/Alpaca/discussions/793"><b>Initial Annoucement in the Alpaca project</b></a>
</p>

## Screenies

| ![Screenie 1](https://jeffser.com/images/pigment/screenie1.png) | ![Screenie 2](https://jeffser.com/images/pigment/screenie2.png) |
|:---------------------------------------------------------------:|:---------------------------------------------------------------:|
| ![Screenie 3](https://jeffser.com/images/pigment/screenie3.png) | ![Screenie 4](https://jeffser.com/images/pigment/screenie4.png) |

## Installation

> [!TIP]
> You may need to [install Flatpak and add the Flathub repository](https://flathub.org/setup) if you haven't already.

### Flathub

Use your system's app store to find Pigment or run this command to install it.

```BASH
flatpak install com.jeffser.Pigment
```

### Package

Pigment is distributed with Flatpak - make sure your distribution supports Flatpak before installing Pigment!

1. Download the latest Flatpak package from the [releases page](https://github.com/Jeffser/Pigment/releases)
2. Open it
3. Install the application
4. Enjoy!

## Translators

Language                | Contributors
:-----------------------|:-----------
🇪🇸 Spanish              | [Jeffry Samuel](https://github.com/jeffser)
🇮🇳 Telugu               | [Aryan Karamtoth](https://github.com/SpaciousCoder78)
🇩🇪 German               | [Magnus Schlinsog](https://github.com/mags0ft)
🇮🇳 Bengali              | [Aritra Saha](https://github.com/olumolu)
🇮🇳 Hindi                | [Aritra Saha](https://github.com/olumolu)
🇨🇿 Czech                | [Amerey](https://github.com/Amereyeu)
🌐 Arabic               | [Zefr0x](https://github.com/zefr0x)
🌐 Occitan              | [Quentin PAGÈS](https://github.com/Mejans)
🇧🇷 Brazilian Portuguese | [Ezilei Correia](https://github.com/ezileicorreia)
🦁 Persian              | [Danial Behzadi](https://github.com/danialbehzadi)

## Thanks

Made using [ColorThief](https://github.com/fengsp/color-thief-py).
